@@ -43,7 +43,7 @@ extern char global_server_type[1024];
 
 extern int activated;
 
-/* The currect directory beeing added and limited */
+/* The current directory beeing added and limited */
 gchar *dir;
 
 /* The 18 checkbox values */
@@ -340,7 +340,7 @@ gboolean dirs_foreach(GtkTreeModel *model, GtkTreePath *path,
 	gtk_tree_model_get(model, iter, i, &dir_val[i], -1);
     }
 
-    /* This is the first/home directory */
+    /* This is the first toplevel home directory */
     if( row_pos == 0 )
     {
 	gtk_tree_model_get(model, iter, 0, &dir, -1);    
@@ -365,12 +365,13 @@ gboolean dirs_foreach(GtkTreeModel *model, GtkTreePath *path,
 	/* Add the rest of the users directories */
 	gtk_tree_model_get(model, iter, 0, &dir, -1);
 
-	/* Need write: 1 2 4 5 6 7 9 */
-	if( dir_val[1] || dir_val[2] || dir_val[4]  
-	||  dir_val[5] || dir_val[6] || dir_val[7] || dir_val[9] )
-          make_dir_chmod(dir, "0777"); /* mkdir -p, no need to check if it exists */
+	/* Need write: 1 2  4 5 6 7 8  10 */
+	if( dir_val[1] || dir_val[2] || dir_val[4] ||  dir_val[5]
+	||  dir_val[6] || dir_val[7] || dir_val[8] || dir_val[10] )
+          make_dir_chmod(dir, "0777"); /* Does mkdir -p, no need to check if it exists */
 	else
-	  make_dir_chmod(dir, "0777"); /* 0755 Noone else can write either... limited by the server */
+	  make_dir_chmod(dir, "0777"); /* 0755 Noone else can write either... limited by the server. */
+
     
 	/* A directory, not the users home */
 	strcat(user_profile, "<Directory ");
@@ -397,7 +398,6 @@ void apply_user(struct w *widgets)
     /* First delete the user from the conf then add it */
     FILE *fp;
     long conf_size;
-    gint active_index;
     int password_length = 0;
     gchar *info;
     char *old_buffer, *new_buffer, *config, *address_buffer, *port_buffer;
@@ -409,6 +409,7 @@ void apply_user(struct w *widgets)
 
     G_CONST_RETURN gchar *username;
     G_CONST_RETURN gchar *groupname;
+    G_CONST_RETURN gchar *comment;
     G_CONST_RETURN gchar *password;
     G_CONST_RETURN gchar *login_from;
     G_CONST_RETURN gchar *max_logins;
@@ -417,7 +418,7 @@ void apply_user(struct w *widgets)
     username = gtk_entry_get_text(GTK_ENTRY(widgets->user_set_entry[0]));
     password = gtk_entry_get_text(GTK_ENTRY(widgets->user_set_entry[1]));
     groupname = gtk_entry_get_text(GTK_ENTRY(widgets->user_set_entry[2]));
-//  Later  comment = gtk_entry_get_text(GTK_ENTRY(widgets->user_set_entry[3]));
+    comment = gtk_entry_get_text(GTK_ENTRY(widgets->user_set_entry[3]));
     login_from = gtk_entry_get_text(GTK_ENTRY(widgets->user_set_entry[5]));
     max_logins = gtk_entry_get_text(GTK_ENTRY(widgets->user_set_spinbutton[0]));
 
@@ -449,7 +450,6 @@ void apply_user(struct w *widgets)
     row_pos = 0; /* Only get the home directory */
     gtk_tree_model_foreach(GTK_TREE_MODEL(widgets->directory_store), (GtkTreeModelForeachFunc) dirs_foreach, widgets);
 
-
     /* Create the user profile... */
 
     /* Home directory */
@@ -470,11 +470,10 @@ void apply_user(struct w *widgets)
     strcat(user_profile, "\n");
 
     /* Require password */
-    active_index = gtk_combo_box_get_active(GTK_COMBO_BOX(widgets->user_set_combo[0]));
-    if( active_index == 0 )
-	strcat(user_profile, "AnonRequirePassword on\n");
+    if( ! gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(widgets->user_set_checkbutton[1])) )
+      strcat(user_profile, "AnonRequirePassword off\n");
     else
-	strcat(user_profile, "AnonRequirePassword off\n");
+      strcat(user_profile, "AnonRequirePassword on\n");
 
     
     /* Maximum logins */
@@ -514,7 +513,7 @@ void apply_user(struct w *widgets)
     
 
     /* If not checked, dont show this user in the statistics (picked up by gprostats) */
-    if( ! gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(widgets->user_set_checkbutton[1])) )
+    if( ! gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(widgets->user_set_checkbutton[2])) )
       strcat(user_profile, "#gplockstats\n");
 
     /* Profile end */
@@ -776,6 +775,6 @@ void apply_user(struct w *widgets)
     /* Populate the conf tab */    
     populate_conf_tab(widgets);
     
-    if( activated )
-      reread_conf(widgets);
+    /* Update the server */
+    reread_conf(widgets);
 }
