@@ -63,7 +63,7 @@ void create_server_settings(struct w *widgets)
 
     /* The servers hostname or IP-Address */
     widgets->server_set_entry[ent] = make_long_entry_with_label(GTK_TABLE(widgets->srv_set_table), _(" The servers IP-address or hostname: "), 0,1,a,b,entry_size);
-    gtk_tooltips_set_tip(tooltips, widgets->server_set_entry[ent], _("ftp.mydomain.org or 192.168.0.100"), NULL);
+    gtk_tooltips_set_tip(tooltips, widgets->server_set_entry[ent], _("ftp.mydomain.org, 192.168.0.100 or 0.0.0.0 which means listen to all network interfaces"), NULL);
     a++; b++; ent++;
 
     /* Alternative server ident Label+Entry+Combo */
@@ -225,7 +225,7 @@ void create_server_settings(struct w *widgets)
 
     /* Default statistics file */
     widgets->server_set_entry[ent] = make_long_entry_with_label(GTK_TABLE(widgets->srv_set_table), _(" Default HTML statistics filepath: "), 0,1,a,b,200);
-    gtk_tooltips_set_tip(tooltips, widgets->server_set_entry[ent], _("This will be set as the default HTML statistics filepath, IE: /var/www/ftp.html"), NULL);
+    gtk_tooltips_set_tip(tooltips, widgets->server_set_entry[ent], _("This will be set as the default HTML statistics filepath, IE: /var/www/ftp.htm"), NULL);
     a++; b++; ent++;
 // End should be added to a settings window.
 
