@@ -54,7 +54,7 @@ user_exists(G_CONST_RETURN gchar *username)
 {
     /* Checks if the system user exists */
     FILE *fp;
-    long size_buffer;
+    long conf_size;
     int x, user_exists = 0;
     char tempname[4096]="";
     char *check_buffer;
@@ -67,13 +67,13 @@ user_exists(G_CONST_RETURN gchar *username)
     else
       {
 	    fseek(fp, 0, SEEK_END);
-	    size_buffer = ftell(fp);
+	    conf_size = ftell(fp);
 	    rewind(fp);
 
-	    check_buffer = allocate(size_buffer);
+	    check_buffer = allocate(conf_size);
 
-	    if( size_buffer > 1 )
-	    while(fgets(check_buffer, size_buffer, fp)!=NULL)
+	    if( conf_size > 1 )
+	    while(fgets(check_buffer, conf_size, fp)!=NULL)
 	    {
 		for(x=0; check_buffer[x]; x++)
 		{
@@ -105,13 +105,13 @@ user_exists(G_CONST_RETURN gchar *username)
     else
       {
 	    fseek(fp, 0, SEEK_END);
-	    size_buffer = ftell(fp);
+	    conf_size = ftell(fp);
 	    rewind(fp);
 
-	    check_buffer = allocate(size_buffer);
+	    check_buffer = allocate(conf_size);
 
-	    if( size_buffer > 1 )
-	    while(fgets(check_buffer, size_buffer, fp)!=NULL)
+	    if( conf_size > 1 )
+	    while(fgets(check_buffer, conf_size, fp)!=NULL)
 	    {
 		for(x=0; check_buffer[x]; x++)
 		{
@@ -143,7 +143,7 @@ group_exists(G_CONST_RETURN gchar *groupname)
 {
     /* Checks if the system group already exists */
     FILE *fp;
-    long size_buffer;
+    long conf_size;
     int x, group_exists=0;
     char tempname[4096]="";
     char *check_buffer;
@@ -156,12 +156,12 @@ group_exists(G_CONST_RETURN gchar *groupname)
     else
       {
 	    fseek(fp, 0, SEEK_END);
-	    size_buffer = ftell(fp);
+	    conf_size = ftell(fp);
 	    rewind(fp);
-	    check_buffer = allocate(size_buffer);
+	    check_buffer = allocate(conf_size);
 
-	    if( size_buffer > 1 )
-	    while(fgets(check_buffer, size_buffer, fp)!=NULL)
+	    if( conf_size > 1 )
+	    while(fgets(check_buffer, conf_size, fp)!=NULL)
 	    {
 		for(x=0; check_buffer[x]; x++)
 		{
@@ -191,12 +191,12 @@ group_exists(G_CONST_RETURN gchar *groupname)
     else
       {
 	    fseek(fp, 0, SEEK_END);
-	    size_buffer = ftell(fp);
+	    conf_size = ftell(fp);
 	    rewind(fp);
-	    check_buffer = allocate(size_buffer);
+	    check_buffer = allocate(conf_size);
 
-	    if( size_buffer > 1 )
-	    while(fgets(check_buffer, size_buffer, fp)!=NULL)
+	    if( conf_size > 1 )
+	    while(fgets(check_buffer, conf_size, fp)!=NULL)
 	    {
 		for(x=0; check_buffer[x]; x++)
 		{
@@ -334,7 +334,7 @@ gchar *get_user_comment(gchar *user)
 {
     /* Gets the users comment from passwd */
     FILE *fp;
-    long size_buffer;
+    long conf_size;
     int x=0, y=0, found_user=0, found_comment=0, count=0;
     char *tempname;
     char *check_buffer;
@@ -350,13 +350,13 @@ gchar *get_user_comment(gchar *user)
     else
       {
 	    fseek(fp, 0, SEEK_END);
-	    size_buffer = ftell(fp);
+	    conf_size = ftell(fp);
 	    rewind(fp);
 
-	    check_buffer = allocate(size_buffer);
+	    check_buffer = allocate(conf_size);
 
-	    if( size_buffer > 1 )
-	    while(fgets(check_buffer, size_buffer, fp)!=NULL)
+	    if( conf_size > 1 )
+	    while(fgets(check_buffer, conf_size, fp)!=NULL)
 	    {
 		for(x=0; check_buffer[x]; x++)
 		{
@@ -558,7 +558,7 @@ int is_banned(char *user)
     FILE *fp;
     char *old_buffer, *user_buffer;
     int ret=0, i=0;
-    long size_buffer;
+    long conf_size;
 
     if((fp=fopen(GP_FTPUSERS, "r"))==NULL)
     {
@@ -566,13 +566,13 @@ int is_banned(char *user)
         return 0;
     }
     fseek(fp, 0, SEEK_END);
-    size_buffer=ftell(fp);
+    conf_size=ftell(fp);
     rewind(fp);
     user_buffer = allocate(8192);
-    old_buffer = allocate(size_buffer);
+    old_buffer = allocate(conf_size);
 
-    if( size_buffer > 1 )
-    while(fgets(old_buffer, size_buffer, fp)!=NULL)
+    if( conf_size > 1 )
+    while(fgets(old_buffer, conf_size, fp)!=NULL)
     {
 	if( strstr(old_buffer, user) )
 	{
@@ -616,7 +616,7 @@ fix_newlines_in_conf()
     /* * then add newlines before <Anonymous and <VirtualHost */
     FILE *fp;
     char *old_buffer, *new_buffer;
-    long size_buffer, allocate_extra=0;
+    long conf_size, allocate_extra=0;
 
     /* First remove any newlines first on all lines in the config */
     /* And see how many new chars we will be adding */
@@ -626,10 +626,10 @@ fix_newlines_in_conf()
        return 0;
     }
     fseek(fp, 0, SEEK_END);
-    size_buffer=ftell(fp);
+    conf_size=ftell(fp);
     rewind(fp);
 
-    old_buffer = allocate(size_buffer+1024);
+    old_buffer = allocate(conf_size+1024);
     if( old_buffer==NULL )
     {
         printf("Cant allocate enough memory for newlines\n");
@@ -637,7 +637,7 @@ fix_newlines_in_conf()
 	return 0;
     }
 
-    new_buffer = allocate(size_buffer+1024);
+    new_buffer = allocate(conf_size+1024);
     if( new_buffer==NULL )
     {
         printf("Cant allocate enough memory for newlines\n");
@@ -646,8 +646,8 @@ fix_newlines_in_conf()
 	return 0;
     }
 
-    if( size_buffer > 1 )
-    while(fgets(old_buffer, size_buffer, fp)!=NULL)
+    if( conf_size > 1 )
+    while(fgets(old_buffer, conf_size, fp)!=NULL)
     {
 	if( old_buffer[0]=='\n' || old_buffer[0]=='\r' )
 	{
@@ -681,10 +681,10 @@ fix_newlines_in_conf()
        return 0;
     }
     fseek(fp, 0, SEEK_END);
-    size_buffer=ftell(fp);
+    conf_size=ftell(fp);
     rewind(fp);
 
-    old_buffer = allocate(size_buffer+1024);
+    old_buffer = allocate(conf_size+1024);
     if( old_buffer==NULL )
     {
         printf("Cant allocate enough memory for newlines\n");
@@ -692,7 +692,7 @@ fix_newlines_in_conf()
 	return 0;
     }
 
-    new_buffer = allocate(size_buffer+1024+allocate_extra);
+    new_buffer = allocate(conf_size+1024+allocate_extra);
     if( new_buffer==NULL )
     {
         printf("Cant allocate enough memory for newlines\n");
@@ -701,8 +701,8 @@ fix_newlines_in_conf()
 	return 0;
     }
 
-    if( size_buffer > 1 )
-    while(fgets(old_buffer, size_buffer, fp)!=NULL)
+    if( conf_size > 1 )
+    while(fgets(old_buffer, conf_size, fp)!=NULL)
     {
 	if( strstr(old_buffer, "<Anonymous") || strstr(old_buffer, "<VirtualHost") )
 	{
