@@ -82,7 +82,7 @@ main(int argc, char *argv[])
 {
     FILE *fp;
     struct user_stats * userlist;
-    long size_buffer;
+    long conf_size;
     uint64_t file_size;
     char *old_buffer, *user, *dir, *action, *file, *datestamp, *welcome, *welcome1, *temp, *convert;
 
@@ -140,6 +140,7 @@ main(int argc, char *argv[])
 	}
     }
 
+    
     printf("\n");
 
     /* Check for user-supplied args */
@@ -187,13 +188,13 @@ main(int argc, char *argv[])
         return 0;
     }
     fseek(fp, 0, SEEK_END);
-    size_buffer = ftell(fp);
+    conf_size = ftell(fp);
     rewind(fp);
 
-    old_buffer = allocate(size_buffer);
+    old_buffer = allocate(conf_size);
 
-    if( size_buffer > 1 )
-    while(fgets(old_buffer, size_buffer, fp)!=NULL)
+    if( conf_size > 1 )
+    while(fgets(old_buffer, conf_size, fp)!=NULL)
     {
 	if( strlen(old_buffer) > 8000 )
 	  continue;
@@ -227,8 +228,8 @@ main(int argc, char *argv[])
     dir = allocate(8192);
     rewind(fp);
 
-    if( size_buffer > 1 )
-    while(fgets(old_buffer, size_buffer, fp)!=NULL)
+    if( conf_size > 1 )
+    while(fgets(old_buffer, conf_size, fp)!=NULL)
     {
 	if( strlen(old_buffer) > 8000 )
 	  continue;
@@ -247,7 +248,7 @@ main(int argc, char *argv[])
 	    }	    
 	    snprintf(userlist[row].dir, 8000, "%s", dir);
 
-	    while(fgets(old_buffer, size_buffer, fp)!=NULL)
+	    while(fgets(old_buffer, conf_size, fp)!=NULL)
 	    {
 		if( strlen(old_buffer) > 8000 )
 		  continue;
@@ -266,7 +267,7 @@ main(int argc, char *argv[])
 		    userlist[row].update = 1;
 
 		    /* Locked .. dont update the welcome message  */
-		    while(fgets(old_buffer, size_buffer, fp)!=NULL)
+		    while(fgets(old_buffer, conf_size, fp)!=NULL)
 		    {
 			if( strlen(old_buffer) > 8000 )
 			  continue;
@@ -302,13 +303,13 @@ main(int argc, char *argv[])
         return 0;
     }
     fseek(fp, 0, SEEK_END);
-    size_buffer = ftell(fp);
+    conf_size = ftell(fp);
     rewind(fp);
     
-    old_buffer = allocate(size_buffer);
+    old_buffer = allocate(conf_size);
 
-    if( size_buffer > 1 )
-    while(fgets(old_buffer, size_buffer, fp)!=NULL )
+    if( conf_size > 1 )
+    while(fgets(old_buffer, conf_size, fp)!=NULL )
     {
 	if( strlen(old_buffer) > 8000 )
 	  continue;
@@ -379,13 +380,17 @@ main(int argc, char *argv[])
     free(action);
     free(file);
 
-    welcome = allocate(8192);
-    welcome1 = allocate(8192);
+    welcome = allocate(16384);
+    welcome1 = allocate(16384);
 
     strcpy(welcome, "Welcome to ");
     strcat(welcome, server_name);
-    strcat(welcome, " \%U\n");
-    strcat(welcome, "\nThe administrator can be reached here: \%E\n");
+    strcat(welcome, " \%U\n\n");
+    
+    strcat(welcome, "You are user \%N out of a maximum of \%M authorized logins.\n");
+    strcat(welcome, "Current time is \%T.\n");
+    strcat(welcome, "The administrator can be reached here: \%E\n");
+
     if( strlen(datestamp) > 3 && strlen(datestamp) < 100 )
     {
 	strcat(welcome, "\nStatistics since: ");
@@ -645,7 +650,15 @@ main(int argc, char *argv[])
     free(welcome);
     free(welcome1);
     free(datestamp);
+
     /* Free the struct */
     free(userlist);
+
+    if( argc < 2 )
+    {
+        printf("\nThe output shown was never written as welcome messages.\n");
+	printf("Add \"-w welcome.msg\" and they will be written, use --help for help.\n\n");
+    }
+    
     return 0;
 }
